ProtobufEncoder

Struct ProtobufEncoder 

pub struct ProtobufEncoder;
An implementation of an Encoder that converts a MetricFamily proto message into the binary wire format of protobuf.

Implementations



impl ProtobufEncoder

pub fn new() -> ProtobufEncoder

Create a new protobuf encoder.